@@ -129,7 +129,7 @@ dumpDatabase() {
 
             if dpkg -s just-search-ltr-database > /dev/null 2>&1; then
                 info "Database = Postgres SEARCH LTR"
-                pg_dump --format custom -v -h "$DB_HOST" -p "$DB_PORT" -U "$SEARCH_LTR_DB_USER" -f "$SEARCH_LTR_DB_BACKUP_FILE" "$SEARCH_LTR_DB_NAME" || error "Failed to dump database into 
+                pg_dump --format custom -v -h "$DB_HOST" -p "$DB_PORT" -U "$SEARCH_LTR_DB_USER" -f "$SEARCH_LTR_DB_BACKUP_FILE" "$SEARCH_LTR_DB_NAME" || error "Failed to dump database into
 $SEARCH_LTR_DB_BACKUP_FILE."
                 chmod 600 "$SEARCH_LTR_DB_BACKUP_FILE"
             fi
@@ -138,16 +138,15 @@ $SEARCH_LTR_DB_BACKUP_FILE."
     info "Successfully created database dump."
 }
 
-# Backups the log files for Apache, Exim, Tomcat, Just Connect, Solr
+# Backups the log files for Apache, Exim, Just Social, Solr
 backupAllLogFiles() {
     log_files_tmp=/tmp/log-files
     getLogFiles $APACHE_LOG_FILES_DIR > $log_files_tmp
     getLogFiles $EXIM_LOG_FILES_DIR >> $log_files_tmp
-    getLogFiles $TOMCAT_LOG_FILES_DIR >> $log_files_tmp
-    getLogFiles $TOMCAT_LOG_FILES_DIR >> $log_files_tmp
-    getLogFiles $HOME_JS/logs >> $log_files_tmp
-    getLogFiles $HOME_JS/search/logs >> $log_files_tmp
     getLogFiles $JUST_LOG_DIR >> $log_files_tmp
+    getLogFiles $JUST_LOG_DIR/backup >> $log_files_tmp
+    getLogFiles $JUST_LOG_DIR/solr >> $log_files_tmp
+    getLogFiles $JUST_LOG_DIR/ejabberd >> $log_files_tmp
     if [ -s $log_files_tmp ]; then
         info "Creating backup of log files..."
         rsync -avz --files-from $log_files_tmp / $LOG_BACKUP_DIR || warn "Could not backup log files to $LOG_BACKUP_DIR"
